@@ -52,16 +52,14 @@ struct _GucharmapChartablePrivate {
 
   int page_first_cell; /* the cell index of the top left corner */
   int active_cell;     /* the active cell index */
-  int old_page_first_cell;
-  int old_active_cell;
 
   /* Drawing */
-  GdkPixmap *pixmap;
   PangoLayout *pango_layout;
 
   /* Zoom popup */
   GtkWidget *zoom_window;
-  GtkWidget *zoom_image;
+  int zoom_image_width;
+  int zoom_image_height;
 
   /* for dragging (#114534) */
   gdouble click_x, click_y; 
@@ -75,6 +73,7 @@ struct _GucharmapChartablePrivate {
   /* Settings */
   guint snap_pow2_enabled : 1;
   guint zoom_mode_enabled : 1;
+  guint font_fallback     : 1;
 };
 
 gint _gucharmap_chartable_cell_column	(GucharmapChartable *chartable,
