@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 2 of the License, or (at your
+ * Free Software Foundation; either version 3 of the License, or (at your
  * option) any later version.
  *
  * This program is distributed in the hope that it will be useful, but
@@ -377,7 +377,11 @@ gucharmap_settings_add_window (GtkWindow *window)
   gboolean maximised, fullscreen;
 
   g_return_if_fail (GTK_IS_WINDOW (window));
+#if GTK_CHECK_VERSION (2,20,0)
+  g_return_if_fail (!gtk_widget_get_realized (GTK_WIDGET (window)));
+#else
   g_return_if_fail (!GTK_WIDGET_REALIZED (window));
+#endif
 
   state = g_slice_new0 (WindowState);
   g_object_set_data_full (G_OBJECT (window), "GamesConf::WindowState",
